/**
 * 
 */
package simpleDB;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;

/**
 * Closes managed objects in the reverse number of their creation.
 * Normally, errors at this stage indicate that worse stuff has occured before,
 * so we simply log the possible exceptions.
 * @author rosmord
 */
public class CloseManager {
	private ArrayList<Object> objects= new ArrayList<Object>();
	
	/**
	 * Manage an object, which should be some kind of JDBC stuff.
	 * @param o
	 */
	
	public void manage(Object o) {
		objects.add(o);
	}
	
	/**
	 * Close all managed objects and clears the manager.
	 * It can be reused.
	 */
	public void close() {
		for (int i= objects.size() -1; i >=0; i--) {
			if (objects.get(i) != null) {
				close(objects.get(i));
			}
		}
		objects.clear();
	}

	/**
	 * @param object
	 */
	private void close(Object object) {
		// It would have been a great idea in JDBC to create a "CloseAble" interface.
		// They did not do it.
		try {
			if (object instanceof Statement) {
				Statement statement = (Statement) object;
				statement.close();
			} else if (object instanceof ResultSet) {
				ResultSet resultSet = (ResultSet) object;
				resultSet.close();
			}
		} catch (SQLException e) {
			e.printStackTrace();
		}
	}
	
	
}
