package simpleDB.utils;

/**
 * This class allows to pass an argument which might be NULL to the SQL methods in a secure way.s
 * @author rosmord
 */
public class PossiblyNullValue {
	private int type;
	private Object value;
	
	/**
	 * Construct a value for NULL for a given type.
	 * @param type
	 * @see java.sql.Types
	 */
	public PossiblyNullValue(int type) {
		super();
		this.type = type;
	}
	
	/**
	 * Construct a value for a given object, which might be null.
	 * @param value the object
	 * @param type the SQL type for the object.
	 * @see java.sql.Types 
	 */
	public PossiblyNullValue(Object value, int type) {
		super();
		this.value = value;
		this.type = type;
	}


	public int getType() {
		return type;
	}
	
	/**
	 * @return the value
	 */
	public Object getValue() {
		return value;
	}
	
	/**
	 * @param value the value to set
	 */
	public void setValue(Object value) {
		this.value = value;
	}
}